##  Adding, Rearranging, and Deleting Slides
You can add, rearrange, and delete slides from a presentation.
  * Adding slides: To add slides after a specific slide, hover over the area below the slide, then click the plus icon that appears. To add slides after a slide that is currently selected, you can also click the plus button in the left-side pane.
You can add a report or diagram to a presentation from the overview page listing reports or diagrams. To do that, on the report or diagram preview, click the three-dot icon > Add to presentation, then select a presentation. A new slide is added to the end of the presentation. The report or diagram must have Can view or Can edit permissions.
  * Rearranging slides: To rearrange slides, drag and drop them within the left-side pane.
  * Deleting slides: To delete a slide, select it in the left-side pane, click the three-dot icon in the lower-right corner, then click Remove.


The intro slide can’t be moved or deleted.
